@@ -9,10 +9,11 @@ Google Spreadsheets client library.
 """
 
 
-__version__ = '3.4.2'
+__version__ = '3.6.0'
 __author__ = 'Anton Burnashev'
 
 
+from .auth import oauth, service_account
 from .client import Client
 from .models import Spreadsheet, Worksheet, Cell
 
@@ -22,7 +23,7 @@ from .exceptions import (
     NoValidUrlKeyFound,
     IncorrectCellLabel,
     WorksheetNotFound,
-    CellNotFound
+    CellNotFound,
 )
 
 
