@@ -18,7 +18,7 @@ from .utils import convert_credentials, extract_id_from_url, finditem
 from .urls import (
     DRIVE_FILES_API_V2_URL,
     DRIVE_FILES_API_V3_URL,
-    DRIVE_FILES_UPLOAD_API_V2_URL
+    DRIVE_FILES_UPLOAD_API_V2_URL,
 )
 
 
@@ -26,15 +26,15 @@ class Client(object):
     """An instance of this class communicates with Google API.
 
     :param auth: An OAuth2 credential object. Credential objects
-                 are those created by the google-auth library.
-                 https://github.com/googleapis/google-auth-library-python
+        created by `google-auth <https://github.com/googleapis/google-auth-library-python>`_.
+
     :param session: (optional) A session object capable of making HTTP requests
-                    while persisting some parameters across requests.
-                    Defaults to `requests.Session <http://docs.python-requests.org/en/master/api/#request-sessions>`_.
+        while persisting some parameters across requests.
+        Defaults to `google.auth.transport.requests.AuthorizedSession <https://google-auth.readthedocs.io/en/latest/reference/google.auth.transport.requests.html#google.auth.transport.requests.AuthorizedSession>`_.
 
     >>> c = gspread.Client(auth=OAuthCredentialObject)
-
     """
+
     def __init__(self, auth, session=None):
         self.auth = convert_credentials(auth)
         self.session = session or AuthorizedSession(self.auth)
@@ -44,27 +44,27 @@ class Client(object):
 
         self.auth.refresh(Request(self.session))
 
-        self.session.headers.update({
-            'Authorization': 'Bearer %s' % self.auth.token
-        })
+        self.session.headers.update(
+            {'Authorization': 'Bearer %s' % self.auth.token}
+        )
 
     def request(
-            self,
-            method,
-            endpoint,
-            params=None,
-            data=None,
-            json=None,
-            files=None,
-            headers=None):
-
+        self,
+        method,
+        endpoint,
+        params=None,
+        data=None,
+        json=None,
+        files=None,
+        headers=None,
+    ):
         response = getattr(self.session, method)(
             endpoint,
             json=json,
             params=params,
             data=data,
             files=files,
-            headers=headers
+            headers=headers,
         )
 
         if response.ok:
@@ -101,9 +101,7 @@ class Client(object):
     def open(self, title):
         """Opens a spreadsheet.
 
-        :param title: A title of a spreadsheet.
-        :type title: str
-
+        :param str title: A title of a spreadsheet.
         :returns: a :class:`~gspread.models.Spreadsheet` instance.
 
         If there's more than one spreadsheet with same title the first one
@@ -114,12 +112,11 @@ class Client(object):
 
         >>> c = gspread.authorize(credentials)
         >>> c.open('My fancy spreadsheet')
-
         """
         try:
             properties = finditem(
                 lambda x: x['name'] == title,
-                self.list_spreadsheet_files(title)
+                self.list_spreadsheet_files(title),
             )
 
             # Drive uses different terminology
@@ -130,24 +127,20 @@ class Client(object):
             raise SpreadsheetNotFound
 
     def open_by_key(self, key):
-        """Opens a spreadsheet specified by `key`.
-
-        :param key: A key of a spreadsheet as it appears in a URL in a browser.
-        :type key: str
+        """Opens a spreadsheet specified by `key` (a.k.a Spreadsheet ID).
 
+        :param str key: A key of a spreadsheet as it appears in a URL in a browser.
         :returns: a :class:`~gspread.models.Spreadsheet` instance.
 
         >>> c = gspread.authorize(credentials)
         >>> c.open_by_key('0BmgG6nO_6dprdS1MN3d3MkdPa142WFRrdnRRUWl1UFE')
-
         """
         return Spreadsheet(self, {'id': key})
 
     def open_by_url(self, url):
         """Opens a spreadsheet specified by `url`.
 
-        :param url: URL of a spreadsheet as it appears in a browser.
-        :type url: str
+        :param str url: URL of a spreadsheet as it appears in a browser.
 
         :returns: a :class:`~gspread.models.Spreadsheet` instance.
 
@@ -156,25 +149,24 @@ class Client(object):
 
         >>> c = gspread.authorize(credentials)
         >>> c.open_by_url('https://docs.google.com/spreadsheet/ccc?key=0Bm...FE&hl')
-
         """
         return self.open_by_key(extract_id_from_url(url))
 
     def openall(self, title=None):
         """Opens all available spreadsheets.
 
-        :param title: (optional) If specified can be used to filter
-                      spreadsheets by title.
-        :type title: str
+        :param str title: (optional) If specified can be used to filter
+            spreadsheets by title.
 
         :returns: a list of :class:`~gspread.models.Spreadsheet` instances.
-
         """
         spreadsheet_files = self.list_spreadsheet_files(title)
 
         if title:
             spreadsheet_files = [
-                spread for spread in spreadsheet_files if title == spread["name"]
+                spread
+                for spread in spreadsheet_files
+                if title == spread["name"]
             ]
 
         return [
@@ -182,55 +174,37 @@ class Client(object):
             for x in spreadsheet_files
         ]
 
-    def create(self, title):
+    def create(self, title, folder_id=None):
         """Creates a new spreadsheet.
 
-        :param title: A title of a new spreadsheet.
-        :type title: str
+        :param str title: A title of a new spreadsheet.
+
+        :param str folder_id: Id of the folder where we want to save
+            the spreadsheet.
 
         :returns: a :class:`~gspread.models.Spreadsheet` instance.
 
-        .. note::
-
-           In order to use this method, you need to add
-           ``https://www.googleapis.com/auth/drive`` to your oAuth scope.
-
-           Example::
-
-              scope = [
-                  'https://spreadsheets.google.com/feeds',
-                  'https://www.googleapis.com/auth/drive'
-              ]
-
-           Otherwise you will get an ``Insufficient Permission`` error
-           when you try to create a new spreadsheet.
-
         """
         payload = {
             'name': title,
-            'mimeType': 'application/vnd.google-apps.spreadsheet'
+            'mimeType': 'application/vnd.google-apps.spreadsheet',
         }
-        r = self.request(
-            'post',
-            DRIVE_FILES_API_V3_URL,
-            json=payload
-        )
+
+        if folder_id is not None:
+            payload['parents'] = [folder_id]
+
+        r = self.request('post', DRIVE_FILES_API_V3_URL, json=payload)
         spreadsheet_id = r.json()['id']
         return self.open_by_key(spreadsheet_id)
 
     def copy(self, file_id, title=None, copy_permissions=False):
         """Copies a spreadsheet.
 
-        :param file_id: A key of a spreadsheet to copy.
-        :type title: str
-
-        :param title: (optional) A title for the new spreadsheet.
-        :type title: str
-
-        :param copy_permissions: (optional) If True, copy permissions from
-               original spreadsheet to new spreadsheet.
-        :type copy_permissions: bool
+        :param str file_id: A key of a spreadsheet to copy.
+        :param str title: (optional) A title for the new spreadsheet.
 
+        :param bool copy_permissions: (optional) If True, copy permissions from
+            the original spreadsheet to the new spreadsheet.
 
         :returns: a :class:`~gspread.models.Spreadsheet` instance.
 
@@ -244,7 +218,7 @@ class Client(object):
            Example::
 
               scope = [
-                  'https://spreadsheets.google.com/feeds',
+                  'https://www.googleapis.com/auth/spreadsheets',
                   'https://www.googleapis.com/auth/drive'
               ]
 
@@ -252,24 +226,14 @@ class Client(object):
            when you try to copy a spreadsheet.
 
         """
-        url = '{0}/{1}/copy'.format(
-            DRIVE_FILES_API_V2_URL,
-            file_id
-        )
+        url = '{0}/{1}/copy'.format(DRIVE_FILES_API_V2_URL, file_id)
 
         payload = {
             'title': title,
-            'mimeType': 'application/vnd.google-apps.spreadsheet'
+            'mimeType': 'application/vnd.google-apps.spreadsheet',
         }
-        params = {
-            'supportsAllDrives': True
-        }
-        r = self.request(
-            'post',
-            url,
-            json=payload,
-            params=params
-        )
+        params = {'supportsAllDrives': True}
+        r = self.request('post', url, json=payload, params=params)
         spreadsheet_id = r.json()['id']
 
         new_spreadsheet = self.open_by_key(spreadsheet_id)
@@ -286,7 +250,7 @@ class Client(object):
                         value=p['emailAddress'],
                         perm_type=p['type'],
                         role=p['role'],
-                        notify=False
+                        notify=False,
                     )
                 except Exception:
                     pass
@@ -296,17 +260,11 @@ class Client(object):
     def del_spreadsheet(self, file_id):
         """Deletes a spreadsheet.
 
-        :param file_id: a spreadsheet ID (aka file ID.)
-        :type file_id: str
+        :param str file_id: a spreadsheet ID (a.k.a file ID).
         """
-        url = '{0}/{1}'.format(
-            DRIVE_FILES_API_V3_URL,
-            file_id
-        )
+        url = '{0}/{1}'.format(DRIVE_FILES_API_V3_URL, file_id)
 
-        params = {
-            'supportsAllDrives': True
-        }
+        params = {'supportsAllDrives': True}
         self.request('delete', url, params=params)
 
     def import_csv(self, file_id, data):
@@ -339,22 +297,19 @@ class Client(object):
             params={
                 'uploadType': 'media',
                 'convert': True,
-                'supportsAllDrives': True
+                'supportsAllDrives': True,
             },
-            headers=headers
+            headers=headers,
         )
 
     def list_permissions(self, file_id):
         """Retrieve a list of permissions for a file.
 
-        :param file_id: a spreadsheet ID (aka file ID.)
-        :type file_id: str
+        :param str file_id: a spreadsheet ID (aka file ID).
         """
         url = '{0}/{1}/permissions'.format(DRIVE_FILES_API_V2_URL, file_id)
 
-        params = {
-            'supportsAllDrives': True
-        }
+        params = {'supportsAllDrives': True}
         r = self.request('get', url, params=params)
 
         return r.json()['items']
@@ -367,30 +322,24 @@ class Client(object):
         role,
         notify=True,
         email_message=None,
-        with_link=False
+        with_link=False,
     ):
         """Creates a new permission for a file.
 
-        :param file_id: a spreadsheet ID (aka file ID.)
-        :type file_id: str
+        :param str file_id: a spreadsheet ID (aka file ID).
         :param value: user or group e-mail address, domain name
-                      or None for 'default' type.
+            or None for 'default' type.
         :type value: str, None
-        :param perm_type: (optional) The account type.
-               Allowed values are: ``user``, ``group``, ``domain``,
-               ``anyone``
-        :type perm_type: str
-        :param role: (optional) The primary role for this user.
-               Allowed values are: ``owner``, ``writer``, ``reader``
-        :type str:
-
-        :param notify: (optional) Whether to send an email to the target user/domain.
-        :type notify: str
-        :param email_message: (optional) An email message to be sent if notify=True.
-        :type email_message: str
-
-        :param with_link: (optional) Whether the link is required for this permission to be active.
-        :type with_link: bool
+        :param str perm_type: (optional) The account type.
+            Allowed values are: ``user``, ``group``, ``domain``, ``anyone``
+        :param str role: (optional) The primary role for this user.
+            Allowed values are: ``owner``, ``writer``, ``reader``
+        :param str notify: (optional) Whether to send an email to the target
+            user/domain.
+        :param str email_message: (optional) An email message to be sent
+            if ``notify=True``.
+        :param bool with_link: (optional) Whether the link is required for this
+            permission to be active.
 
         Examples::
 
@@ -420,37 +369,26 @@ class Client(object):
             'value': value,
             'type': perm_type,
             'role': role,
-            'withLink': with_link
+            'withLink': with_link,
         }
 
         params = {
             'sendNotificationEmails': notify,
             'emailMessage': email_message,
-            'supportsAllDrives': 'true'
+            'supportsAllDrives': 'true',
         }
 
-        self.request(
-            'post',
-            url,
-            json=payload,
-            params=params
-        )
+        self.request('post', url, json=payload, params=params)
 
     def remove_permission(self, file_id, permission_id):
         """Deletes a permission from a file.
 
-        :param file_id: a spreadsheet ID (aka file ID.)
-        :type file_id: str
-        :param permission_id: an ID for the permission.
-        :type permission_id: str
+        :param str file_id: a spreadsheet ID (aka file ID.)
+        :param str permission_id: an ID for the permission.
         """
         url = '{0}/{1}/permissions/{2}'.format(
-            DRIVE_FILES_API_V2_URL,
-            file_id,
-            permission_id
+            DRIVE_FILES_API_V2_URL, file_id, permission_id
         )
 
-        params = {
-            'supportsAllDrives': True
-        }
+        params = {'supportsAllDrives': True}
         self.request('delete', url, params=params)
